@@ -1,4 +1,4 @@
-# (C) Copyright 2018-2021 by Rocky Bernstein
+# (C) Copyright 2018-2022 by Rocky Bernstein
 #
 #  This program is free software; you can redistribute it and/or
 #  modify it under the terms of the GNU General Public License
@@ -97,7 +97,10 @@ class _Marshaller:
         self.python_version = python_version
 
     def dump(self, x):
-        if isinstance(x, types.CodeType) and PYTHON_VERSION_TRIPLE[:2] != self.python_version:
+        if (
+            isinstance(x, types.CodeType)
+            and PYTHON_VERSION_TRIPLE[:2] != self.python_version[:2]
+        ):
             raise RuntimeError(
                 "code type passed for version %s but we are running version %s"
                 % (version_tuple_to_str(), self.python_version)
@@ -105,12 +108,12 @@ class _Marshaller:
         try:
             self.dispatch[type(x)](self, x)
         except KeyError:
-            if isinstance(x, Code2):
-                self.dispatch[Code2](self, x)
-                return
-            elif isinstance(x, Code3):
+            if isinstance(x, Code3):
                 self.dispatch[Code3](self, x)
                 return
+            elif isinstance(x, Code2):
+                self.dispatch[Code2](self, x)
+                return
             else:
                 for tp in type(x).mro():
                     func = self.dispatch.get(tp)
@@ -804,9 +807,11 @@ class _FastUnmarshaller:
             self.bufpos += 1
             return _load_dispatch[c](self)
         except KeyError:
-            raise ValueError("bad marshal code: %c (%d)" % (c, Ord(c)))
+            exception = ValueError("bad marshal code at position %d: %c"
+                             % (self.bufpos - 1,c))
         except IndexError:
-            raise EOFError
+            exception = EOFError
+        raise exception
 
     def load_null(self):
         return _NULL
@@ -1029,7 +1034,7 @@ def load(f, python_version=None):
 
 
 @builtinify
-def dumps(x, version=version, python_version=None):
+def dumps(x, version=version, python_version=PYTHON_VERSION_TRIPLE):
     # XXX 'version' is ignored, we always dump in a version-0-compatible format
     buffer = []
     m = _Marshaller(buffer.append, python_version=python_version)
