@@ -1,6 +1,7 @@
 # Much of this is borrowed from Python's Lib/dis.py
 
 from math import copysign
+from typing import Dict
 
 
 def code2num(code, i):
@@ -11,12 +12,12 @@ def code2num(code, i):
 
 
 def num2code(num):
-    return (num & 0xFF, num >> 8)
+    return num & 0xFF, num >> 8
 
 
-# The inspect module interrogates this dictionary to build its
+# The `inspect` module interrogates this dictionary to build its
 # list of CO_* constants. It is also used by pretty_flags to
-# turn the co_flags field into a human readable list.
+# turn the co_flags field into a human-readable list.
 COMPILER_FLAG_NAMES = {
     0x00000001: "OPTIMIZED",
     0x00000002: "NEWLOCALS",
@@ -50,13 +51,15 @@ PYPY_COMPILER_FLAG_NAMES = {
     0x10000000: "PYPY_ACCEPT_NULL_BYTES",
 }
 
-# Invert above dictionary so we can look up a bit value
+# Invert above dictionary, so we can look up a bit value
 # from the compile flag name
-COMPILER_FLAG_BIT = dict([v, k] for (k, v) in COMPILER_FLAG_NAMES.items())
+COMPILER_FLAG_BIT: Dict[str, int] = dict(
+    (v, k) for (k, v) in COMPILER_FLAG_NAMES.items()
+)
 
 # Allow us to access by just name, prefixed with CO. e.g
 # CO_OPTIMIZED, CO_NOFREE
-globals().update(dict(["CO_" + k, v] for (k, v) in COMPILER_FLAG_BIT.items()))
+globals().update(dict(("CO_" + k, v) for (k, v) in COMPILER_FLAG_BIT.items()))
 
 
 def co_flags_is_async(co_flags):
@@ -88,7 +91,7 @@ def is_negative_zero(n):
 
 
 def better_repr(v):
-    """Work around Python's unorthogonal and unhelpful repr() for primitive float
+    """Work around Python's not orthogonal and unhelpful repr() for primitive float
     and complex."""
     if isinstance(v, float):
         # float values 'nan' and 'inf' are not directly
@@ -106,7 +109,7 @@ def better_repr(v):
         imag = better_repr(v.imag)
         # FIXME: we could probably use repr() in most cases
         # sort out when that's possible.
-        # The below is however round-tripable, and Python's repr() isn't.
+        # The below round trips, and Python's repr() isn't.
         return "complex(%s, %s)" % (real, imag)
     elif isinstance(v, tuple):
         if len(v) == 1:
